# This file was auto-generated by Fern from our API Definition.

from ..core.api_error import ApiError
from ..types.http_validation_error import HttpValidationError


class UnprocessableEntityError(ApiError):
    def __init__(self, body: HttpValidationError):
        super().__init__(status_code=422, body=body)



# This file was auto-generated by Fern from our API Definition.

from ..core.unchecked_base_model import UncheckedBaseModel
from .chat_completion_prediction_content_param_content import ChatCompletionPredictionContentParamContent
import typing
from ..core.pydantic_utilities import IS_PYDANTIC_V2
import pydantic


class ChatCompletionPredictionContentParam(UncheckedBaseModel):
    content: ChatCompletionPredictionContentParamContent
    type: typing.Literal["content"] = "content"

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

import typing

FileProcessingStatus = typing.Union[typing.Literal["pending", "parsing", "embedding", "completed", "error"], typing.Any]



# This file was auto-generated by Fern from our API Definition.

from ..core.unchecked_base_model import UncheckedBaseModel
import datetime as dt
import typing
import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2


class SystemMessage(UncheckedBaseModel):
    """
    A message generated by the system. Never streamed back on a response, only used for cursor pagination.

    Args:
        id (str): The ID of the message
        date (datetime): The date the message was created in ISO format
        name (Optional[str]): The name of the sender of the message
        content (str): The message content sent by the system
    """

    id: str
    date: dt.datetime
    name: typing.Optional[str] = None
    message_type: typing.Literal["system_message"] = "system_message"
    otid: typing.Optional[str] = None
    sender_id: typing.Optional[str] = None
    step_id: typing.Optional[str] = None
    content: str = pydantic.Field()
    """
    The message content sent by the system
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

import typing
from .base_64_image import Base64Image
from .letta_image import LettaImage
from .url_image import UrlImage

ImageContentSource = typing.Union[Base64Image, LettaImage, UrlImage]



# This file was auto-generated by Fern from our API Definition.

from ..core.unchecked_base_model import UncheckedBaseModel
import typing
import pydantic
from .file_processing_status import FileProcessingStatus
import datetime as dt
from ..core.pydantic_utilities import IS_PYDANTIC_V2


class FileMetadata(UncheckedBaseModel):
    """
    Representation of a single FileMetadata
    """

    id: typing.Optional[str] = pydantic.Field(default=None)
    """
    The human-friendly ID of the File
    """

    source_id: str = pydantic.Field()
    """
    The unique identifier of the source associated with the document.
    """

    file_name: typing.Optional[str] = pydantic.Field(default=None)
    """
    The name of the file.
    """

    original_file_name: typing.Optional[str] = pydantic.Field(default=None)
    """
    The original name of the file as uploaded.
    """

    file_path: typing.Optional[str] = pydantic.Field(default=None)
    """
    The path to the file.
    """

    file_type: typing.Optional[str] = pydantic.Field(default=None)
    """
    The type of the file (MIME type).
    """

    file_size: typing.Optional[int] = pydantic.Field(default=None)
    """
    The size of the file in bytes.
    """

    file_creation_date: typing.Optional[str] = pydantic.Field(default=None)
    """
    The creation date of the file.
    """

    file_last_modified_date: typing.Optional[str] = pydantic.Field(default=None)
    """
    The last modified date of the file.
    """

    processing_status: typing.Optional[FileProcessingStatus] = pydantic.Field(default=None)
    """
    The current processing status of the file (e.g. pending, parsing, embedding, completed, error).
    """

    error_message: typing.Optional[str] = pydantic.Field(default=None)
    """
    Optional error message if the file failed processing.
    """

    created_at: typing.Optional[dt.datetime] = pydantic.Field(default=None)
    """
    The creation date of the file.
    """

    updated_at: typing.Optional[dt.datetime] = pydantic.Field(default=None)
    """
    The update date of the file.
    """

    is_deleted: typing.Optional[bool] = pydantic.Field(default=None)
    """
    Whether this file is deleted or not.
    """

    content: typing.Optional[str] = pydantic.Field(default=None)
    """
    Optional full-text content of the file; only populated on demand due to its size.
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

from ..core.unchecked_base_model import UncheckedBaseModel
import typing
import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2


class UpdateSsemcpServer(UncheckedBaseModel):
    """
    Update an SSE MCP server
    """

    server_name: typing.Optional[str] = pydantic.Field(default=None)
    """
    The name of the server
    """

    server_url: typing.Optional[str] = pydantic.Field(default=None)
    """
    The URL of the server (MCP SSE client will connect to this URL)
    """

    token: typing.Optional[str] = pydantic.Field(default=None)
    """
    The access token or API key for the MCP server (used for SSE authentication)
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

import typing

AgentType = typing.Union[
    typing.Literal[
        "memgpt_agent",
        "memgpt_v2_agent",
        "react_agent",
        "workflow_agent",
        "split_thread_agent",
        "sleeptime_agent",
        "voice_convo_agent",
        "voice_sleeptime_agent",
    ],
    typing.Any,
]
